@@ -14,20 +14,21 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from calculate.consolegui import qt
-import urllib2
+import urllib.request as urllib2
 import OpenSSL, hashlib
 
-from more import show_msg, LabelWordWrap, show_question, get_ip_mac, get_icon
-from create_cert import RequestCreate
-from client_class import HTTPSClientCertTransport, Client_suds
+from .more import show_msg, LabelWordWrap, show_question, get_ip_mac, get_icon
+from .create_cert import RequestCreate
+from .client_class import HTTPSClientCertTransport, Client_suds
 from calculate.lib.utils.files import readFile
 import os
 
 class CertClass (qt.QWidget):
     def __init__(self, parent, ClientObj, window):
         self.ClientObj = ClientObj
-        qt.QWidget.__init__(self)
+        super().__init__()
         
         # get_cert_path
         self.default_cert_path = ClientObj.path_to_cert
@@ -130,13 +131,12 @@ class CertClass (qt.QWidget):
             self.client = Client_suds(url, \
                     transport = HTTPSClientCertTransport(None, None, \
                     cert_path, parent = self.ClientObj))
-        except (KeyboardInterrupt, urllib2.URLError), e:
+        except (KeyboardInterrupt, urllib2.URLError) as e:
             try:
-                show_msg(e.reason.strerror.decode('utf-8') \
-                                , _("Closing. Connection error."), self)
+                # show_msg(e.reason.strerror.decode('utf-8'), _("Closing. Connection error."), self)
+                show_msg(e.reason.strerror, _("Closing. Connection error."), self)
             except  (UnicodeDecodeError, UnicodeEncodeError):
-                show_msg(e.reason.strerror, \
-                                _("Closing. Connection error."), self)
+                show_msg(e.reason.strerror, _("Closing. Connection error."), self)
             return 1
         except (UnicodeDecodeError, UnicodeEncodeError):
             show_msg (_('Enter the hostname or the IP address'),
@@ -147,7 +147,7 @@ class CertClass (qt.QWidget):
             server_host_name = self.client.service.get_server_host_name()
         except AttributeError:
             return 1
-        except urllib2.URLError, e:
+        except urllib2.URLError as e:
             _print ('method send in CertificateClass Exception')
             show_msg (e, _("Not connected!"), self)
             return 1
@@ -181,7 +181,7 @@ class CertClass (qt.QWidget):
         try:
             res = self.client.service.post_client_request(request = data, \
                                     ip = ip, mac = mac, client_type = 'gui')
-        except urllib2.URLError, e:
+        except urllib2.URLError as e:
             _print ('method end_send in CertificateClass Exception')
             show_msg (e, _("Not connected!"), self)
             return 1
@@ -226,7 +226,7 @@ class CertClass (qt.QWidget):
             client = Client_suds(url, \
                         transport = HTTPSClientCertTransport(None, None, \
                         cert_path, parent = self.ClientObj))
-        except (KeyboardInterrupt, urllib2.URLError), e:
+        except (KeyboardInterrupt, urllib2.URLError) as e:
             show_msg(_("Error code: %s") %e, _("Closing. Connection error."),\
                      self)
             return 1
@@ -237,7 +237,7 @@ class CertClass (qt.QWidget):
         client.wsdl.services[0].setlocation(url)
         try:
             server_host_name = client.service.get_server_host_name()
-        except urllib2.URLError, e:
+        except urllib2.URLError as e:
             _print ('method get in CertificateClass Exception')
             show_msg (e, _("Not connected!"), self)
             return 1
@@ -246,15 +246,14 @@ class CertClass (qt.QWidget):
             show_msg(_('Request %s not found on the client`s side') \
                             %(cert_path + server_host_name + '.csr'))
             return 1
-
         request = readFile(cert_path + server_host_name + '.csr')
         md5 = hashlib.md5()
-        md5.update(request)
+        md5.update(request.encode('UTF-8'))
         md5sum = md5.hexdigest()
 
         try:
             result = client.service.get_client_cert(req_id, md5sum)
-        except urllib2.URLError, e:
+        except urllib2.URLError as e:
             _print ('get_client_cert in CertificateClass Exception')
             show_msg (e, _("Not connected!"))
             return 1
@@ -262,7 +261,7 @@ class CertClass (qt.QWidget):
         cert = result[0][0]
         try:
             ca_root = result[0][1]
-        except Exception, e:
+        except Exception as e:
             ca_root = None
 #            show_msg(e.message)
         if cert == '1':
@@ -303,7 +302,7 @@ class CertClass (qt.QWidget):
             root_cert_md5 = cl_client_cert_dir + "/ca/cert_list"
 
             md5 = hashlib.md5()
-            md5.update(ca_root)
+            md5.update(ca_root.encode('UTF-8'))
             md5sum = md5.hexdigest()
             _print ("md5sum = ", md5sum)
 
