@@ -14,8 +14,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 from calculate.consolegui import qt
-from more import LabelWordWrap, _print, get_system_rgb, ParameterWindow, dpivalue
+from .more import LabelWordWrap, _print, get_system_rgb, ParameterWindow, dpivalue
 
 DEBUG_LEVEL = 0
 
@@ -23,13 +25,13 @@ DEBUG_LEVEL = 0
 def debug(level, *args):
     if level <= DEBUG_LEVEL:
         for s in args:
-            print s,
-        print
+            print(s, end=' ')
+        print()
 
 
 class MethodNameWgt(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        qt.QWidget.__init__(self, parent)
+        super().__init__(parent)
         self._parent = parent
         self.ClientObj = ClientObj
 
@@ -39,7 +41,6 @@ class MethodNameWgt(qt.QWidget):
         self.setStyleSheet("QWidget#ControlButton "
                            "{background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
                            "stop: 0 #111111, stop: 0.95 #777777, stop: 1 #666666);}")
-
         self.hlayout = qt.QHBoxLayout(self)
         self.hlayout.setAlignment(qt.Qt.AlignLeft | qt.Qt.AlignVCenter)
         self.hlayout.setContentsMargins(28, 0, 0, 0)
@@ -104,13 +105,14 @@ class MethodNameWgt(qt.QWidget):
 
 class ControlButtonWgt(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        qt.QWidget.__init__(self, parent)
+        super().__init__(parent)
         self._parent = parent
         self.ClientObj = ClientObj
 
         # Set style
         self.setAttribute(qt.Qt.WA_StyledBackground)
         self.setObjectName('ControlButton')
+        
         self.setStyleSheet("QWidget#ControlButton "
                            "{background-color: %s;}"%
                            get_system_rgb(self, ParameterWindow))
@@ -180,7 +182,7 @@ class ControlButtonWgt(qt.QWidget):
 
     def add_custom_button(self, Group, x, y, brief=False,
                             next_button_text=""):
-        self.del_button()
+        # self.del_button()
         buttons = self._parent.MainFrameWgt.buttons
         self.button_widget = qt.QWidget(self)
         end_layout = qt.QHBoxLayout(self.button_widget)
@@ -200,7 +202,8 @@ class ControlButtonWgt(qt.QWidget):
             else:
                 button = qt.QPushButton(self)
                 self.customs.append(button)
-                button.setText(field.label.decode('utf-8'))
+                # button.setText(field.label.decode('utf-8'))
+                button.setText(field.label)
                 button.clicked.connect(self.button_disabled)
                 button.clicked.connect(callback)
                 button.setMinimumWidth(62)
@@ -217,7 +220,7 @@ class ControlButtonWgt(qt.QWidget):
 
     def add_standart_button(self, Group, x, y, brief=False, \
                             next_button_text=""):
-        self.del_button()
+        # self.del_button()
         main_frame = self._parent.MainFrameWgt
         # add 1 (or 2) button ok (next) [and previous]
         self.button_widget = qt.QWidget(self)
@@ -241,11 +244,12 @@ class ControlButtonWgt(qt.QWidget):
         main_frame = self._parent.MainFrameWgt
         self.cancel_button = qt.QPushButton(self)
         if main_frame.has_errors:
-            self.cancel_button.setText(_('Close').decode('utf-8'))
+            self.cancel_button.setText(_('Close'))
         else:
-            self.cancel_button.setText(_('Cancel').decode('utf-8'))
+            self.cancel_button.setText(_('Cancel'))
 
         self.cancel_button.clicked.connect(self.button_disabled)
+        
         self.cancel_button.clicked.connect(self.clear_method_cache)
         method_name = main_frame.method_name
         self.cancel_button.clicked.connect(
@@ -330,25 +334,26 @@ class ControlButtonWgt(qt.QWidget):
         if self.button_widget:
             self.hlayout.removeWidget(self.button_widget)
             self.button_widget.close()
-            self.button_widget = None
+            # self.button_widget = None
         if self.prev_button:
             self.prev_button.close()
-            self.prev_button = None
+            # self.prev_button = None
         if self.cancel_button:
             self.cancel_button.close()
-            self.cancel_button = None
+            # self.cancel_button = None
         if self.next_button:
             self.next_button.close()
-            self.next_button = None
+            # self.next_button = None
         if self.customs:
             for but in self.customs:
                 but.close()
-                self.customs = None
+                # self.customs = None
         if self.default_button:
-            self.default_button = None
+            pass
+            # self.default_button = None
 
     def pre_add_button(self):
-        self.del_button()
+        # self.del_button()
         # add 1 (or 2) button ok (next) [and previous]
         self.button_widget = qt.QWidget(self)
         end_layout = qt.QHBoxLayout(self.button_widget)
@@ -375,7 +380,7 @@ class ControlButtonWgt(qt.QWidget):
         self.hlayout.addWidget(self.button_widget)
 
     def clear_pid_cache(self):
-        self.button_disabled()
+        # self.button_disabled()
         self.clear_proc_cache_button.setDisabled(True)
         sid = int(self.ClientObj.sid)
         res = self.ClientObj.client.service.clear_pid_cache(sid, self.pid)
@@ -386,13 +391,12 @@ class ControlButtonWgt(qt.QWidget):
         if res:
             _print(_('Error closing the process'))
 
-        from calculate.consolegui.application.ConnectionTabs \
-            import SelectedMethodWgt
+        from .ConnectionTabs import SelectedMethodWgt
 
         if type(self.window()) == SelectedMethodWgt:
             self.window().close()
         else:
-            self.del_button()
+            # self.del_button()
             self.hide()
             self._parent.back()
 
@@ -406,46 +410,47 @@ class ControlButtonWgt(qt.QWidget):
                 res = self.ClientObj.client.service.clear_method_cache \
                     (sid, method)
                 lerror = self.ClientObj.param_objects[method]['error']
-                while len(lerror) > 0:
-                    lerror.pop()
+                if(lerror):
+                    while len(lerror) > 0:
+                        lerror.pop()
             except Exception as e:
-                print e
-        from calculate.consolegui.application.ConnectionTabs \
-            import SelectedMethodWgt
+                print(e)
+        from .ConnectionTabs import SelectedMethodWgt
 
         if type(self.window()) == SelectedMethodWgt:
             self.window().close()
         else:
-            self.del_button()
+            # self.del_button()
             self.hide()
             self._parent.back()
 
     def button_disabled(self):
-        if self.next_button:
-            self.next_button.setDisabled(True)
-        if self.prev_button:
-            self.prev_button.setDisabled(True)
-        if self.cancel_button:
-            self.cancel_button.setDisabled(True)
-        if self.clear_proc_cache_button:
-            self.clear_proc_cache_button.setDisabled(True)
-        if self.customs:
-            for but in self.customs:
-                but.setDisabled(True)
+
+        # if self.next_button:
+        #     self.next_button.setDisabled(True)
+        # if self.prev_button:
+        #     self.prev_button.setDisabled(True)
+        # if self.cancel_button:
+        #     self.cancel_button.setDisabled(True)
+        # if self.clear_proc_cache_button:
+        #     self.clear_proc_cache_button.setDisabled(True)
+        # if self.customs:
+        #     for but in self.customs:
+        #         but.setDisabled(True)
         self.ClientObj.app.processEvents()
 
     def button_enabled(self):
-        if self.next_button:
-            self.next_button.setEnabled(True)
-        if self.prev_button:
-            self.prev_button.setEnabled(True)
-        if self.cancel_button:
-            self.cancel_button.setEnabled(True)
-        if self.clear_proc_cache_button:
-            self.clear_proc_cache_button.setEnabled(True)
-        if self.customs:
-            for but in self.customs:
-                but.setEnabled(True)
+        # if self.next_button:
+        #     self.next_button.setEnabled(True)
+        # if self.prev_button:
+        #     self.prev_button.setEnabled(True)
+        # if self.cancel_button:
+        #     self.cancel_button.setEnabled(True)
+        # if self.clear_proc_cache_button:
+        #     self.clear_proc_cache_button.setEnabled(True)
+        # if self.customs:
+        #     for but in self.customs:
+        #         but.setEnabled(True)
         self.ClientObj.app.processEvents()
 
     def keyPressEvent(self, e):
