@@ -14,15 +14,16 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from calculate.consolegui import qt
 
-from more import ButtonMenu, FlowLayout, get_sid, ClientServiceThread, \
+from .more import ButtonMenu, FlowLayout, get_sid, ClientServiceThread, \
                  get_view_params, show_msg, client_list_methods, get_system_rgb, \
                  get_icon, dpivalue
 
 class DisplayMethod(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        super(DisplayMethod, self).__init__(parent)
+        super().__init__(parent)
         self.ClientObj = ClientObj
         self._parent = parent
         self.setAttribute(qt.Qt.WA_DeleteOnClose)
@@ -70,21 +71,25 @@ class DisplayMethod(qt.QWidget):
         # display all groups and methods
         for group in guiMethods:
             if len (group.split('.')) > 1:
-                group_name = group.split('.')[0].encode('utf-8')
-                sub_group = group.split('.')[1].encode('utf-8')
-                if not self.groupbox_dict.has_key(group_name):
-                    gb = qt.QGroupBox(group_name.decode('utf-8'), self)
+                # group_name = group.split('.')[0].encode('utf-8')
+                # sub_group = group.split('.')[1].encode('utf-8')
+
+                group_name = group.split('.')[0]
+                sub_group = group.split('.')[1]
+                if group_name not in self.groupbox_dict:
+                    # gb = qt.QGroupBox(group_name.decode('utf-8'), self)
+                    gb = qt.QGroupBox(group_name, self)
                     gb.setStyleSheet(groupbox_style)
                     gb.setAlignment(qt.Qt.AlignLeft)
                     self.groupbox_dict[group_name] = gb
 
-                if not self.layout_dict.has_key(group_name):
+                if group_name not in self.layout_dict:
                     self.layout_dict[group_name] = \
                                     FlowLayout(self.groupbox_dict[group_name])
 
                 attrubute_list = []
                 sub_group_list = []
-                if self.button_list.has_key(sub_group):
+                if sub_group in self.button_list:
                     attrubute_list = self.button_list[sub_group][0]
                     sub_group_list = self.button_list[sub_group][1]
                 self.button_list[sub_group] = []
@@ -107,16 +112,16 @@ class DisplayMethod(qt.QWidget):
                 self.button_list[sub_group].append(Button)
                 continue
 
-            if not self.groupbox_dict.has_key(group):
+            if group not in self.groupbox_dict:
                 gb = qt.QGroupBox(group, self)
                 gb.setStyleSheet(groupbox_style)
                 self.groupbox_dict[group] = gb
                 gb.setAlignment(qt.Qt.AlignLeft)
 
-            if not self.layout_dict.has_key(group):
+            if group not in self.layout_dict:
                 self.layout_dict[group] = FlowLayout(self.groupbox_dict[group])
-            view_name_sort = filter(lambda x: guiMethods[group].index(x) % 3 \
-                                    == 1, guiMethods[group])
+            view_name_sort = list(filter(lambda x: guiMethods[group].index(x) % 3 \
+                                    == 1, guiMethods[group]))
             view_name_sort.sort()
             guiMethods_sort = []
             for sort_name in view_name_sort:
@@ -135,7 +140,7 @@ class DisplayMethod(qt.QWidget):
 #                except (UnicodeDecodeError, UnicodeEncodeError):
 #                    Button.setStatusTip(sub_group)
  
-                if not self.button_list.has_key(group):
+                if group not in self.button_list:
                     self.button_list[group] = []
                 self.button_list[group].append(Button)
 
@@ -147,7 +152,7 @@ class DisplayMethod(qt.QWidget):
                                                        qt.Qt.AlignTop)
             self.groupbox_dict[group].setLayout(self.layout_dict[group])
 
-        keys_sort = guiMethods.keys()
+        keys_sort = list(guiMethods.keys())
         keys_sort.sort()
         for group in keys_sort:
             if len (group.split('.')) > 1:
@@ -247,7 +252,7 @@ class DisplayMethod(qt.QWidget):
 
         self.ClientObj.sid = get_sid(self.ClientObj.client)
         expert = None
-        if self.ClientObj.param_objects.has_key(method_name):
+        if method_name in self.ClientObj.param_objects:
             self.ClientObj.param_objects[method_name]['step'] = 0
             if self.ClientObj.param_objects[method_name]['expert_changed']:
                 expert = True
@@ -266,17 +271,20 @@ class DisplayMethod(qt.QWidget):
     def onActivated_after(self, view):
         self.setDisabled(False)
         #self.con_lost_lbl.hide()
+        
         if type(view) == Exception:
-            if hasattr (view.message, 'message'):
-                view = view.message
 
-            if type(view.message) == tuple:
-                if view.message[0] == 403:
-                    msg = _('Permission denied')
-                else:
-                    msg = ' '.join(map(lambda x: str(x), view.message))
-            else:
-                msg = view.message.__str__()
+            # if hasattr (view, 'message'):
+            #     view = view.message
+
+            # if type(view) == tuple:
+            #     if view.message[0] == 403:
+            #         msg = _('Permission denied')
+            #     else:
+            #         msg = ' '.join(map(lambda x: str(x), view.message))
+            # else:
+            #     msg = view.message.__str__()
+            msg = str(view)
             show_msg(msg)
             return 1
 
@@ -284,7 +292,7 @@ class DisplayMethod(qt.QWidget):
         self._parent.main_frame.viewport().setStyleSheet('')
 
         # set new Title
-        if self.ClientObj.method_names.has_key(method_name):
+        if method_name in self.ClientObj.method_names:
             view_method = self.ClientObj.method_names[method_name]
         else:
             view_method = method_name
@@ -317,7 +325,8 @@ class DisplayMethod(qt.QWidget):
             self.ClientObj.MainWidget.left_frame.show()
 
             try:
-                new_title = sub_group[0].split('.')[0].decode('utf-8')
+                # new_title = sub_group[0].split('.')[0].decode('utf-8')
+                new_title = sub_group[0].split('.')[0]
             except (UnicodeDecodeError, UnicodeEncodeError):
                 pass
             if self.ClientObj.MainWidget.left_frame.old_title:                
@@ -340,12 +349,12 @@ class DisplayMethod(qt.QWidget):
 
 class StartWidget(qt.QWidget):
     def __init__(self, parent):
-        super(StartWidget, self).__init__(parent)
+        super().__init__(parent)
         self.setAttribute(qt.Qt.WA_DeleteOnClose)
 
 class ConnectLostLabel (qt.QWidget):
     def __init__(self, text, parent, reconnect = False):
-        qt.QWidget.__init__(self, parent.layout_wgt)
+        super().__init__(parent.layout_wgt)
         self._parent = parent
         if parent.main_frame.isEnabled():
             parent.left_frame.setDisabled(True)
