@@ -14,9 +14,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from calculate.consolegui import qt
-import time, urllib2
-from calculate.core.client.function import create_obj
+import time
+import urllib.request as urllib2
+# from calculate.core.client.function import create_obj
+from .utils import create_obj
 
 try:
     from calculate.update.update_info import UpdateInfo
@@ -24,10 +27,9 @@ except ImportError:
     UpdateInfo = None
 import dbus
 
-from ReturnMessage import ReturnedMessage
-from calculate.consolegui.application.pid_information import client_pid_info, \
-    client_list_pid
-from more import show_msg, get_sid, _print, get_icon
+from .ReturnMessage import ReturnedMessage
+from .pid_information import client_pid_info, client_list_pid
+from .more import show_msg, get_sid, _print, get_icon
 
 # class MySignal(qt.QObject):
 #    sig = qt.Signal(str, str)
@@ -37,7 +39,7 @@ class TrayUpdateSystem(qt.QThread):
     started_sig = qt.Signal(str)
 
     def __init__(self, target, parent=None):
-        qt.QThread.__init__(self, parent)
+        super().__init__(parent)
         self._parent = target
 
     def run(self):
@@ -56,12 +58,15 @@ class TrayUpdateSystem(qt.QThread):
         sid = get_sid(self._parent.localhost_ClientObj.client)
 
         try:
-            param_object = create_obj(self._parent.localhost_ClientObj.client,
-                                      "update")
+            param_object = create_obj(self._parent.localhost_ClientObj.client, "update")
+            print("DEBUG")
+            print(sid)
+            print(param_object)
             meth_result_temp = \
-                self._parent.localhost_ClientObj.client.service.update(
-                    sid, param_object)
-        except Exception, e:
+                self._parent.localhost_ClientObj.client.service[0]['update'](sid, param_object)
+                # self._parent.localhost_ClientObj.client.service.update(sid, param_object)
+            print(meth_result_temp)
+        except Exception as e:
             msg = e.message
             if type(e.message) == tuple:
                 msg = ' '.join(map(lambda x: str(x), list(e.message)))
@@ -151,7 +156,7 @@ class TrayIcon(qt.QSystemTrayIcon):
     default_theme_name = 'Tango'
 
     def __init__(self, parent):
-        super(TrayIcon, self).__init__(parent)
+        super().__init__(parent)
         self._parent = parent
         self.actions = []
 
