@@ -14,162 +14,106 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from calculate.consolegui import qt
-import urllib2 as u2
+import urllib.request as u2
 if hasattr(u2,"ssl"):
     u2.ssl._create_default_https_context = u2.ssl._create_unverified_context
 import os, re, sys
-from calculate.core.datavars import DataVarsCore
+
 
 import calculate.contrib
 from suds.transport.http import HttpTransport
 
-try:
-    from pyopenssl_wrapper import PyOpenSSLSocket
-except ImportError:
-    PYOPENSSL_AVAILABLE = False
-else:
-    PYOPENSSL_AVAILABLE = True
-
-import httplib #http.client in python3
+# try:
+from .pyopenssl_wrapper import PyOpenSSLSocket
+import http.client as httplib
 from suds.transport import Transport
 from suds.properties import Unskin
-from cookielib import CookieJar, DefaultCookiePolicy
+from http.cookiejar import CookieJar, DefaultCookiePolicy
 
 import socket, ssl
 import OpenSSL, hashlib
 from suds.client import Client
 from logging import getLogger
-from calculate.core.client.cert_verify import verify, VerifyError
+# from calculate.core.client.cert_verify import verify, VerifyError
 from calculate.lib.utils.files import readFile
 
-from more import show_msg, show_question, LabelWordWrap
+from .more import show_msg, show_question, LabelWordWrap
 
 flag = 0
 log = getLogger(__name__)
 
+# #TODO fix translation for verify
+# _ = lambda x: x
+# from calculate.lib.cl_lang import setLocalTranslate
+# setLocalTranslate('cl_core3', sys.modules["__name__"])
 
-class SUDSHTTPRedirectHandler(u2.HTTPRedirectHandler):
-    def redirect_request(self, req, fp, code, msg, headers, newurl):
-        """Return a Request or None in response to a redirect.
+from calculate.core.datavars import DataVarsCore
 
-        This is called by the http_error_30x methods,
-        it was taken from the original Python version and modified
-        to use POST when redirection takes place.
-        This allows a SOAP message to be redirected without a loss
-        of content.
-        """
-        m = req.get_method()
-        if (code in (301, 302, 303, 307) and m in ("GET", "HEAD")
-            or code in (301, 302, 303) and m == "POST"):
-            newurl = newurl.replace(' ', '%20')
-            newheaders = dict((k,v) for k,v in req.headers.items()
-                              if k.lower() not in ("content-length", "content-type")
-                             )
-            log.debug("Redirecting to %s", newurl)
-            return u2.Request(newurl,
-                              data=req.data, # here we pass the original data
-                              headers=newheaders,
-                              origin_req_host=req.get_origin_req_host(),
-                              unverifiable=True,
-                              )
-        else:
-            raise u2.HTTPError(req.get_full_url(), code, msg, headers, fp)
+class VerifyError(Exception):
+    def __init__(self, value):
+        self.value = value
 
-class MyHTTPResponse(httplib.HTTPResponse):
-
-  def __init__(self, sock, debuglevel=0, strict=0, method=None):
-
-    httplib.HTTPResponse.__init__(self, sock, debuglevel, strict, method)
-
-class CheckingHTTPSConnection(httplib.HTTPSConnection):
-  """based on httplib.HTTPSConnection code - extended to support 
-  server certificate verification and client certificate authorization"""
-
-  response_class = MyHTTPResponse
-
-  FORCE_SSL_VERSION = None
-  SERVER_CERT_CHECK = True # might be turned off when a workaround is needed
+    def __str__(self):
+        return repr(self.value)
 
 
-  def __init__(self, host, ca_certs=None, cert_verifier=None,
-               keyobj=None, certobj=None, **kw):
-    """cert_verifier is a function returning either True or False
-    based on whether the certificate was found to be OK,
-    keyobj and certobj represent internal PyOpenSSL structures holding
-    the key and certificate respectively.
-    """
-    httplib.HTTPSConnection.__init__(self, host, **kw)
-    self.ca_certs = ca_certs
-    self.cert_verifier = cert_verifier
-    self.keyobj = keyobj
-    self.certobj = certobj
-
-  def connect(self):
-    sock = socket.create_connection((self.host, self.port), self.timeout)
-    if hasattr(self, '_tunnel_host') and self._tunnel_host:
-        self.sock = sock
-        self._tunnel()
-    if self.FORCE_SSL_VERSION:
-      add = {'ssl_version': self.FORCE_SSL_VERSION}
+# check recall of server certificate 
+def verify(server_cert, crl_path, flag):
+    import OpenSSL
+    certobj = OpenSSL.crypto.load_certificate(OpenSSL.SSL.FILETYPE_PEM,
+                                              server_cert)
+    serverSerial = certobj.get_serial_number()
+    Issuer = certobj.get_issuer().get_components()
+    CN, L = None, None
+    for i in Issuer:
+        if i[0] == 'CN':
+            CN = i[1]
+        elif i[0] == 'L':
+            L = i[1]
+    if CN and len(CN) > 2:
+        crl_file = crl_path + CN
+    elif L:
+        try:
+            host = L.split(':')[0]
+        except Exception:
+            if not flag:
+                print(_('The CN and L fields in the CA certificate are '
+                        'incorrect!'))
+            return 0
+        crl_file = crl_path + host
     else:
-      add = {}
-    if self.SERVER_CERT_CHECK and self.ca_certs:
-      add['cert_reqs'] = ssl.CERT_REQUIRED
-    else:
-      add['cert_reqs'] = ssl.CERT_NONE
-    # try to use PyOpenSSL by default
-    if PYOPENSSL_AVAILABLE:
-      wrap_class = PyOpenSSLSocket
-      add['keyobj'] = self.keyobj
-      add['certobj'] = self.certobj
-      add['keyfile'] = self.key_file
-      add['certfile'] = self.cert_file
-    else:
-      wrap_class = ssl.SSLSocket
-    self.sock = wrap_class(sock, ca_certs=self.ca_certs, **add)
-      #if self.cert_verifier and self.SERVER_CERT_CHECK:
-      #  if not self.cert_verifier(self.sock.getpeercert()):
-      #    raise Exception("Server certificate did not pass security check.",
-      #                    self.sock.getpeercert())
+        if not flag:
+            print(_('The CN and L fields in the CA certificate are incorrect!'))
+        return 0
 
-class CheckingHTTPSHandler(u2.HTTPSHandler):
+    if not os.path.exists(crl_file):
+        if not flag:
+            print(_("This certificate cannot be verified in the CRL."))
+        return 0
 
-  def __init__(self, ca_certs=None, cert_verifier=None,
-               client_certfile=None, client_keyfile=None,
-               client_keyobj=None, client_certobj=None,
-              *args, **kw):
-    """cert_verifier is a function returning either True or False
-    based on whether the certificate was found to be OK"""
-    u2.HTTPSHandler.__init__(self, *args, **kw)
-    self.ca_certs = ca_certs
-    self.cert_verifier = cert_verifier
-    self.client_keyfile = client_keyfile # filename
-    self.client_certfile = client_certfile # filename
-    self.keyobj = client_keyobj
-    self.certobj = client_certobj
-    # FOR DEBUG
-    # self.set_http_debuglevel(100)
+    with open(crl_file, 'r') as _crl_file:
+        crl = "".join(_crl_file.readlines())
 
-  def https_open(self, req):
-    def open(*args, **kw):
-      new_kw = dict(ca_certs=self.ca_certs,
-                    cert_verifier=self.cert_verifier,
-                    cert_file=self.client_certfile,
-                    key_file=self.client_keyfile,
-                    keyobj=self.keyobj,
-                    certobj=self.certobj)
-      new_kw.update(kw)
-      return CheckingHTTPSConnection(*args, **new_kw)
-    return self.do_open(open, req)
+    if crl == '':
+        return 0
+    crl_object = OpenSSL.crypto.load_crl(OpenSSL.crypto.FILETYPE_PEM, crl)
 
-  https_request = u2.AbstractHTTPHandler.do_request_
+    revoked_objects = crl_object.get_revoked()
 
+    for rvk in revoked_objects:
+        if serverSerial == int(rvk.get_serial(), 16):
+            print(_("This certificate has been revoked!"))
+            print (_("Serial") + ': %s\n' % rvk.get_serial() +
+                   _("Revoke date") + _(': %s') % rvk.get_rev_date())
 
+            raise VerifyError('CRL Exception')
+    return 0
 
 class AddServerCert (qt.QDialog):
     def __init__(self, parent, ClientObj, cert):
-        super(AddServerCert, self).__init__()
+        super().__init__()
         self.ClientObj = ClientObj
         self.parent = parent
         self.cert = cert
@@ -296,7 +240,7 @@ class AddServerCert (qt.QDialog):
         show_msg (_('Server certificate added to trusted') +'\n'+ \
                   (self.parent.trusted_path + filename),_('Certificate added'))
         self.flag = 3
-        from conf_connection import FrameConnection
+        from .conf_connection import FrameConnection
         self.ConnectWidget = FrameConnection(self, self.ClientObj)
         self.ConnectWidget.connect_to_host(host, self.ClientObj.port)
 
@@ -333,9 +277,39 @@ class Client_suds(Client):
         if not os.path.exists(self.CRL_PATH):
             os.makedirs(self.CRL_PATH)
 
-class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
-    """based on httplib.HTTPSConnection code - extended to support 
-    server certificate verification and client certificate authorization"""
+class SUDSHTTPRedirectHandler(u2.HTTPRedirectHandler):
+    def redirect_request(self, req, fp, code, msg, headers, newurl):
+        """Return a Request or None in response to a redirect.
+
+        This is called by the http_error_30x methods,
+        it was taken from the original Python version and modified
+        to use POST when redirection takes place.
+        This allows a SOAP message to be redirected without a loss
+        of content.
+        """
+        m = req.get_method()
+        if (code in (301, 302, 303, 307) and m in ("GET", "HEAD")
+            or code in (301, 302, 303) and m == "POST"):
+            newurl = newurl.replace(' ', '%20')
+            newheaders = dict((k,v) for k,v in req.headers.items()
+                              if k.lower() not in ("content-length", "content-type")
+                             )
+            log.debug("Redirecting to %s", newurl)
+            return u2.Request(newurl,
+                              data=req.data, # here we pass the original data
+                              headers=newheaders,
+                              origin_req_host=req.get_origin_req_host(),
+                              unverifiable=True,
+                              )
+        else:
+            raise u2.HTTPError(req.get_full_url(), code, msg, headers, fp)
+
+class CheckingClientHTTPSConnection(httplib.HTTPSConnection):
+    """based on httplib.HTTPSConnection code"""
+    response_class = httplib.HTTPResponse
+
+    FORCE_SSL_VERSION = None
+    SERVER_CERT_CHECK = True # might be turned off when a workaround is needed
 
     def __init__(self, ClientObj, cert_path, host, ca_certs=None,
                  cert_verifier=None, keyobj=None, certobj=None, **kw):
@@ -344,30 +318,39 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
         keyobj and certobj represent internal PyOpenSSL structures holding
         the key and certificate respectively.
         """
-        CheckingHTTPSConnection.__init__(self, host, ca_certs, cert_verifier,
-                                         keyobj, certobj, **kw)
+        httplib.HTTPSConnection.__init__(self, host, **kw)
+        self.ca_certs = ca_certs
+        self.cert_verifier = cert_verifier
+        self.keyobj = keyobj
+        self.certobj = certobj
         self.ClientObj = ClientObj
         self.cert_path = cert_path
         self.CRL_PATH = os.path.join(cert_path, 'ca/crl/')
 
     def connect(self):
+        # print("DEBUG connect checkClientHTTPS")
         sock = socket.create_connection((self.host, self.port), self.timeout)
         if hasattr(self, '_tunnel_host') and self._tunnel_host:
+            # print("Tunnel connection")
             self.sock = sock
             self._tunnel()
 
         user_root_cert = self.ClientObj.VarsApi.Get('core.cl_user_root_cert')
+        # print(f"user_root_cert : \n {user_root_cert}")
         homePath = self.ClientObj.VarsApi.Get('ur_home_path')
         user_root_cert = user_root_cert.replace("~",homePath)
+        # print(f"user_root_cert2 : \n {user_root_cert}")
         result_user_root = 1
 
         while True:
             if os.path.exists(user_root_cert):
                 result_user_root = self.connect_trusted_root(sock,
                                               user_root_cert, self.CRL_PATH)
+            # print(f"result_user_root : \n {result_user_root}")
             if result_user_root == 1:
                 glob_root_cert = self.ClientObj.VarsApi.Get(
                     'core.cl_glob_root_cert')
+                # print(f"glob_root_cert : \n {glob_root_cert}")
                 result_root_con = 1
                 if os.path.exists(glob_root_cert):
                     sock = socket.create_connection((self.host, self.port),
@@ -377,6 +360,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
                         self._tunnel()
                     result_root_con = self.connect_trusted_root(sock,
                                               glob_root_cert, self.CRL_PATH)
+                    # print(f"result_root_con : \n {result_root_con}")
                 if result_root_con == 1:
                     sock = socket.create_connection((self.host, self.port),
                                         self.timeout, self.source_address)
@@ -510,7 +494,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
         client.wsdl.services[0].setlocation(url)
         try:
             cert = client.service.get_ca()
-        except u2.URLError, e:
+        except u2.URLError as e:
             _print ('client.service.get_ca in client_class Exception')
             cert = '0'
 
@@ -589,18 +573,15 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
             else:
                 add = {}
             add['cert_reqs'] = ssl.CERT_REQUIRED
-            # try to use PyOpenSSL by default
-            if PYOPENSSL_AVAILABLE:
-                wrap_class = PyOpenSSLSocket
-                add['keyobj'] = self.keyobj
-                add['certobj'] = self.certobj
-                add['keyfile'] = self.key_file
-                add['certfile'] = self.cert_file
-            else:
-                wrap_class = ssl.SSLSocket
-            self.sock = wrap_class(sock, ca_certs=self.ca_certs, **add)
+            add['keyobj'] = self.keyobj
+            add['certobj'] = self.certobj
+            add['keyfile'] = self.key_file
+            add['certfile'] = self.cert_file
+            self.sock = PyOpenSSLSocket(sock, ca_certs=self.ca_certs, **add)
             return 0
-        except:
+        except Exception as e:
+            # print("DEBUG except in connect trusted root")
+            # print(e)
             return 1
 
     def connect_trusted_server(self, sock, crl_certs):
@@ -623,49 +604,51 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
                 else:
                     add = {}
                 add['cert_reqs'] = ssl.CERT_NONE
-                # try to use PyOpenSSL by default
-                if PYOPENSSL_AVAILABLE:
-                    wrap_class = PyOpenSSLSocket
-                    add['keyobj'] = self.keyobj
-                    add['certobj'] = self.certobj
-                    add['keyfile'] = self.key_file
-                    add['certfile'] = self.cert_file
-                else:
-                    wrap_class = ssl.SSLSocket
-                self.sock = wrap_class(sock, ca_certs=self.ca_certs, **add)
-
+                add['keyobj'] = self.keyobj
+                add['certobj'] = self.certobj
+                add['keyfile'] = self.key_file
+                add['certfile'] = self.cert_file
+                self.sock = PyOpenSSLSocket(sock, ca_certs=self.ca_certs, **add)
                 return 0
-	    except OpenSSL.SSL.Error, e:
-	        if type(e.message) == list:
-		    if type(e.message[0]) == tuple:
-		        for i in e.message[0]:
-			    sys.stdout.write(i+' ')
-			    sys.stdout.flush()
-			sys.stdout.write('\n')
-			sys.stdout.flush()
+            
+            except OpenSSL.SSL.Error as e:
+                if type(e.message) == list:
+                    if type(e.message[0]) == tuple:
+                        for i in e.message[0]:
+                            sys.stdout.write(i+' ')
+                            sys.stdout.flush()
+                        sys.stdout.write('\n')
+                        sys.stdout.flush()
                     else:
-		        _print (e.message)
-	        else:
-		    _print (e.message)
+                        _print (e.message)
+                else:
+                    _print (e.message)
                 HTTPSClientCertTransport.filename = None
                 return 1
-            except Exception, e:
+
+            except Exception as e:
                 _print (e)
                 HTTPSClientCertTransport.filename = None
                 return 1
         else:
             return self.add_server_cert(server_cert)
 
-class CheckingClientHTTPSHandler(CheckingHTTPSHandler):
+class CheckingClientHTTPSHandler(u2.HTTPSHandler):
     def __init__(self, ClientObj, cert_path, ca_certs=None, cert_verifier=None,
                  client_certfile=None, client_keyfile=None,
                  client_keyobj=None, client_certobj=None,
                  *args, **kw):
         """cert_verifier is a function returning either True or False
         based on whether the certificate was found to be OK"""
-        CheckingHTTPSHandler.__init__(self, ca_certs, cert_verifier,
-                                  client_keyfile, client_certfile,
-                                  client_keyobj, client_certobj)
+        u2.HTTPSHandler.__init__(self, *args, **kw)
+        self.ca_certs = ca_certs
+        self.cert_verifier = cert_verifier
+        self.client_keyfile = client_keyfile # filename
+        self.client_certfile = client_certfile # filename
+        self.keyobj = client_keyobj
+        self.certobj = client_certobj
+        # FOR DEBUG
+        # self.set_http_debuglevel(100)
         self.ClientObj = ClientObj
         self.cert_path = cert_path
 
@@ -697,40 +680,31 @@ class HTTPSClientCertTransport(HttpTransport):
         self.cert = cert
         self.cert_path = path_to_cert
         if key:
-            client_certobj = OpenSSL.crypto.load_certificate \
-                              (OpenSSL.SSL.FILETYPE_PEM, file(cert).read())
-            if password:
-                client_keyobj = OpenSSL.crypto.load_privatekey \
-                        (OpenSSL.SSL.FILETYPE_PEM, file(key).read(), 
-                         str(password))
-            else:
-                import M2Crypto
-                bio = M2Crypto.BIO.openfile(key)
-                rsa = M2Crypto.m2.rsa_read_key(bio._ptr(),lambda *unused: None)
-                if not rsa:
-                    raise OpenSSL.crypto.Error
-                client_keyobj = OpenSSL.crypto.load_privatekey \
-                                (OpenSSL.SSL.FILETYPE_PEM, file(key).read())
+            with open(cert) as cert_file:
+                client_certobj = OpenSSL.crypto.load_certificate \
+                                (OpenSSL.SSL.FILETYPE_PEM, cert_file.read())
+                if password:
+                    with open(key) as key_file:
+                        client_keyobj = OpenSSL.crypto.load_privatekey \
+                                (OpenSSL.SSL.FILETYPE_PEM, key_file.read(), 
+                                password)
+                else:
+                    import M2Crypto
+                    bio = M2Crypto.BIO.openfile(key)
+                    rsa = M2Crypto.m2.rsa_read_key(bio._ptr(),lambda *unused: b"")
+                    if not rsa:
+                        raise OpenSSL.crypto.Error
+                    with open(key) as key_file:
+                        client_keyobj = OpenSSL.crypto.load_privatekey(OpenSSL.SSL.FILETYPE_PEM, 
+                            key_file.read())
 
         Unskin(self.options).update(kwargs)
         self.cookiejar = CookieJar(DefaultCookiePolicy())
         self.cookie_callback = cookie_callback
         self.user_agent_string = user_agent_string
         log.debug("Proxy: %s", self.options.proxy)
-        #TODO to be removed:
-        # artifacts from old times:
         
-        # from dslib.network import ProxyManager
-        # proxy_handler = ProxyManager.HTTPS_PROXY.create_proxy_handler()
-        # proxy_auth_handler = ProxyManager.HTTPS_PROXY.create_proxy_auth_handler()
-
-        # apparently, dslib simply returned None on create_proxy_auth_handler
-        # if this is ever needed, probably use urllib2.ProxyBasicAuthHandler
-        proxy_auth_handler = None
-        # and create_proxy_handler SHOULD HAVE eval'd to this:
-        # proxy_handler = urllib2.ProxyHandler({"https" : "https://hostname"})
-        # but because no hostname was given, it also just returned None
-        proxy_handler = None
+        
         if ca_certs or (client_keyfile and client_certfile) \
                     or (client_keyobj  and client_certobj):
             https_handler = CheckingClientHTTPSHandler(parent,
@@ -747,13 +721,26 @@ class HTTPSClientCertTransport(HttpTransport):
                                        u2.HTTPCookieProcessor(self.cookiejar),
                                        https_handler)
         
-        #these two literally do nothing right now
-        if proxy_handler:
-            self.urlopener.add_handler(proxy_handler)
-        if proxy_auth_handler:
-            self.urlopener.add_handler(proxy_auth_handler)
+        # relic from old times:
+        # from dslib.network import ProxyManager
+        # proxy_handler = ProxyManager.HTTPS_PROXY.create_proxy_handler()
+        # proxy_auth_handler = ProxyManager.HTTPS_PROXY.create_proxy_auth_handler()
 
-        self.urlopener.addheaders = [('User-agent', self.user_agent_string)]
+        # apparently, dslib simply returned None on create_proxy_auth_handler
+        # if this is ever needed, probably use urllib2.ProxyBasicAuthHandler
+        # proxy_auth_handler = None
+        # and create_proxy_handler SHOULD HAVE eval'd to this:
+        # proxy_handler = urllib2.ProxyHandler({"https" : "https://hostname"})
+        # but because no hostname was given, it also just returned None
+        # proxy_handler = None
+
+        #these two literally do nothing right now
+        # if proxy_handler:
+        #     self.urlopener.add_handler(proxy_handler)
+        # if proxy_auth_handler:
+        #     self.urlopener.add_handler(proxy_auth_handler)
+
+        self.urlopener.addheaders = [('User-agent', str(self.user_agent_string))]
 
 ###############################################################################
 
@@ -823,7 +810,7 @@ def get_CRL(path_to_cert):
 
                 client.set_parameters (path_to_cert, None, None)
                 new_crl = client.service.get_crl()
-            except VerifyError, e:
+            except VerifyError as e:
                 _print (e.value)
                 #rm_ca_from_trusted(ca)
                 sys.exit()
