@@ -15,12 +15,13 @@
 #  limitations under the License.
 
 
+from __future__ import absolute_import
 from calculate.consolegui import qt
-from more import TopMenu, HelpMenu#, FlowLayout
+from .more import TopMenu, HelpMenu#, FlowLayout
 
 class MainMenu(qt.QWidget):
     def __init__(self, parent):
-        qt.QWidget.__init__(self, parent)
+        super().__init__(parent)
 #        self.hlayout = FlowLayout(self)
         self.hlayout = qt.QHBoxLayout(self)
         self.hlayout.setAlignment(qt.Qt.AlignLeft)
