@@ -14,16 +14,17 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import os
 
 from calculate.consolegui import qt
 
-from more import LabelWordWrap, FileOpenWgt, show_msg, show_question, \
+from .more import LabelWordWrap, FileOpenWgt, show_msg, show_question, \
                  client_list_methods, get_icon, dpivalue
 
 class ToolsWidget (qt.QWidget):
     def __init__(self, parent, ClientObj, window):
-        qt.QWidget.__init__(self)
+        super().__init__()
         self.vlayout = qt.QVBoxLayout(self)
         self.vlayout.setAlignment(qt.Qt.AlignTop)
         self.vlayout.setAlignment(qt.Qt.AlignRight)
@@ -113,7 +114,7 @@ class ToolsWidget (qt.QWidget):
                 os.remove(ClientObj.user_config)
                 ClientObj.create_user_config()
                 ClientObj.read_user_config(ClientObj.user_config)
-            except Exception, e:
+            except Exception as e:
                 show_msg (e, 'Clear Config Error')
             finally:
                 self.create(parent, ClientObj)
@@ -121,7 +122,7 @@ class ToolsWidget (qt.QWidget):
 
 class ToolTabWidget(qt.QTabWidget):
     def __init__(self, parent, ClientObj):
-        qt.QTabWidget.__init__(self, parent)
+        super().__init__(parent)
         self.ClientObj = ClientObj
 
         self.GuiWidget = ToolGui(self, ClientObj)
@@ -185,7 +186,7 @@ class ToolTabWidget(qt.QTabWidget):
 # Gui tools in ToolTabWidget
 class ToolGui(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        qt.QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.user_config = ClientObj.user_config
         self._parent = parent
 
@@ -328,7 +329,7 @@ class ToolGui(qt.QWidget):
 # Other tools in ToolTabWidget
 class ToolOther(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        qt.QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.user_config = ClientObj.user_config
         self._parent = parent
 
@@ -486,7 +487,7 @@ class ToolOther(qt.QWidget):
             # reset unsaved changes flag
             self._parent.changed_flag = False
             if ClientObj.client:
-                from session_function import client_post_cert
+                from .session_function import client_post_cert
                 ClientObj.lang = self.lang_ComboBox.itemData \
                                            (self.lang_ComboBox.currentIndex())
                 if ClientObj.client:
@@ -496,7 +497,7 @@ class ToolOther(qt.QWidget):
                         return
                     ClientObj.methods_list = client_list_methods \
                                             (ClientObj.sid, ClientObj.client)
-                    from DisplayMethod import DisplayMethod
+                    from .DisplayMethod import DisplayMethod
                     if type (ClientObj.MainWidget.MainFrameWgt) \
                                                             == DisplayMethod:
                         ClientObj.MainWidget.display_methods()
